# Project Information

```{toctree}
:maxdepth: 1

Changelog <changes>
Backlog <backlog>
```

## Prior art
- https://github.com/saschpe/rapport
- https://github.com/nedbat/dinghy
- https://github.com/kneth/gh-utils
- https://github.com/slackapi/slack-github-action
- Many more.
